#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-cssselect%{psuffix}
VCS: https://src.suse.de/pool/python-cssselect#3f0bbe920d0c123ec693d751744c5b6ed4f3ff81
Version:        1.2.0
Release:        5.152
Summary:        CSS3 selectors for Python
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/scrapy/cssselect
Source:         https://github.com/scrapy/cssselect/archive/v%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module lxml}
BuildRequires:  %{python_module pytest}
%endif
%python_subpackages

%description
cssselect parses CSS3 Selectors and translates them to XPath 1.0
expressions. Such expressions can be used in lxml or another XPath engine to
find the matching elements in an XML or HTML document.

This module used to live inside of lxml as lxml.cssselect before it was
extracted as a stand-alone project.

%prep
%setup -q -n cssselect-%{version}

%build
%python_build

%install
%if !%{with test}
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
%pytest
%endif

%if !%{with test}
%files %{python_files}
%{python_sitelib}/*
%license LICENSE
%doc README.rst CHANGES AUTHORS
%endif

%changelog
* Fri Apr 21 2023 dmueller@suse.com
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 mcepl@suse.com
- Make calling of %%{sle15modernpython} optional.
* Mon Nov  7 2022 yarunachalam@suse.com
- Update to 1.2.0
  * Drop support for Python 2.7, 3.4-3.6, add support for Python 3.7-3.11.
  * Add type annotations (PEP 484 and PEP 561).
  * More features from the CSS Selectors Level 4:
  * The ``:is()`` pseudo-class.
  * The ``:where()`` pseudo-class.
  * The ``:has()`` pseudo-class, with some limitations.
  * Fix parsing ``:scope`` after a comma.
  * Add parentheses to fix condition precedence in some cases.
  * Private API changes related to the removal of the Python 2 support:
  * Remove ``_unicode`` and ``_unichr`` aliases from ``csselect.parser``.
  * Remove ``_basestring`` and ``_unicode`` aliases from ``csselect.xpath``.
  * Deprecate ``csselect.xpath._unicode_safe_getattr()`` and change it to just
    call ``getattr()``.
  * Include tests in the PyPI tarball.
  * Many CI additions and improvements.
  * Improve the test coverage.
* Fri Sep 20 2019 tchvatal@suse.com
- Switch to multibuild to avoid build cycle with lxml
* Fri Sep 13 2019 tchvatal@suse.com
- Update to 1.1.0:
  * Support for the :scope selector, which allows to access immediate children of a selector.
  * Support for the |E syntax for type selectors without a namespace.
  * A new selector method, canonical, returns the CSS expression of the selector, as a string.
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Sat Jan  6 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 1.0.3:
  * Fix artifact uploads to pypi
- changes from version 1.0.2:
  * Drop support for Python 2.6 and Python 3.3.
  * Fix deprecation warning in Python 3.6.
  * Minor cleanups.
* Wed Mar 29 2017 tbechtold@suse.com
- update to 1.0.1:
  * Add support for Python 3.6.
  * Documentation hosted `on Read the Docs <https://cssselect.readthedocs.io/>`_
  * Add code coverage reports.
  * Fix ``:nth-*(an+b)`` pseudo-classes selectors.
    (except ``*:nth-child()`` which looks untranslatable to XPath 1.0.)
  * Distribute as universal wheel.
  * Add support for Python 3.3, 3.4 and 3.5.
  * Drop support for Python 2.5 as testing is getting difficult.
  * Improve tests on pseudo-elements.
- Switch to singlespec approach
* Sat Nov 23 2013 p.drouand@gmail.com
- Update to version 0.9.1
  + **Backward incompatible change from 0.9**:
    :meth:`~GenericTranslator.selector_to_xpath` defaults to ignoring
    pseudo-elements, as it did in 0.8 and previous versions.
    (:meth:`~GenericTranslator.css_to_xpath` doesn’t change.)
  + Drop official support for Python 2.4 and 3.1,
    as testing was becoming difficult. Nothing will break overnight,
    but future releases may on may not work on these versions.
    Older releases will remain available on PyPI.
- Changes from 0.9
  + Add parser support for :attr:`functional pseudo-elements
    <Selector.pseudo_element>`.
  + This version accidentally introduced a backward incompatible change:
    :meth:`~GenericTranslator.selector_to_xpath` defaults to rejecting
    pseudo-elements instead of ignoring them.
- Remove useless CFLAGS definition
- Add README.rst, CHANGES and AUTHORS in package documentation
* Tue Jul  9 2013 arun@gmx.de
- Packaged LICENSE file
  fixes bnc#828513
  Bug 828513 - LICENSE not packaged in python3-cssselect 0.8
* Thu Mar 28 2013 arun@gmx.de
- updated to 0.8
  Changelog (http://pythonhosted.org/cssselect/#changelog):
    Released on 2013-03-15.
    Improvements:
    [#22] Let extended translators override what XPathExpr class is used
    [#19] Use the built-in lang() XPath function for implementing the :lang() pseudo-class with XML documents. This is probably faster than ancestor-or-self::.
    Bug fixes:
    [#14] Fix non-ASCII pseudo-classes. (Invalid selector instead of crash.)
    [#20] As per the spec, elements containing only whitespace are not considered empty for the :empty pseudo-class.
* Mon Jan 14 2013 saschpe@suse.de
- Minimal cleanup
* Tue Jan  8 2013 iacobcatalin@gmail.com
- Initial package 0.7.1
